@@ -2,6 +2,8 @@ import os
 import telethon
 import requests
 from bot.config import Config
+import asyncio
+import re
 import functools
 from telethon.errors import BadRequestError
 from telethon.tl.functions.channels import EditAdminRequest, EditBannedRequest
@@ -104,4 +106,4 @@ is_bot_admin = is_bot_admin()
 only_groups = only_groups()
 only_pm = only_pm()
 
-# =================== CONSTANT ===================
\ No newline at end of file
+# =================== CONSTANT ===================
